#!/usr/bin/env bash

#
# install-symlinks.sh
#
# Script for installing symlinks to these rc files into your home directory.
# It's assumed that your home directory is the directory immediately above this
# one.
#
# Colin McCabe
#

die() {
	echo "$@"
	exit 1
}

copy_ssh_old=0
for file in .bashrc .ssh .profile; do
    if [ -f ../$file ]; then
        if [ -L ../$file ]; then
            :
        else
            echo "moving old $file to $file-old"
            mv -f ../$file ../$file-old
            if [ $file == .ssh ]; then
                copy_ssh_old=1
            fi
        fi
    fi
done

BASEDIR=`pwd`
for file in ${BASEDIR}/.[^.]*; do
	# get base file name, like ".gitconfig"
	basefile=`basename ${file}`

	# get relative file name, like "cmccabe-etc/.gitconfig"
	relfile=`echo ${file} | sed 's_.*/\([^/]*/[^/]*\)$_\1_'`

	# skip files which we don't want to link
	[ "${basefile}" == ".git" ] && continue
	[ "${basefile}" == ".gitignore" ] && continue

	pushd .. > /dev/null
	if [ -L ${basefile} ]; then
		# Someone already created this link. Pass over it in silence
		:
	elif [ ! -a ${basefile} ]; then
		# Create the link
		ln -s ${relfile} || die "failed to link ${relfile}"
		echo "created ${relfile}..."
	elif [ -f ${basefile} ]; then
		echo "${basefile} already exists as a regular file"
	else
		echo "${basefile} already exists"
	fi
	popd > /dev/null
done

if [ $copy_ssh_old -eq 1 ]; then
    echo "copying files from .ssh-old to .ssh"
    cp -f ../.ssh-old/* ../.ssh
    echo "chmod 600 ../.ssh/config"
    chmod 600 ../.ssh/*
fi
